@@ -112,66 +112,6 @@ class Processor:
         self.last_time = self.db.get_now()
         self.universal_basetime = datetime.datetime(1970, 1, 1, 0, 0, 0, 0, pytz.UTC)
 
-    def _execute_safely(self, entrypoint, item):
-        # logger.info("SAFE EXECUTION STARTED!")
-        # We cap runtime at 60 seconds
-        timeout = 30
-        failure = None
-        result = None
-        try:
-            watchdog = fk.utils.Watchdog.Watchdog(timeout)
-            # logger.info("££££ Entry")
-            result, failure = entrypoint(item, self.config)
-            # logger.info("££££ Exit")
-        except fk.utils.Watchdog.Watchdog:
-            logger.warning("Watchdag triggered exception")
-            failure = f"execution timed out after {timeout} seconds"
-        except Exception as e:
-            logger.warning("")
-            logger.warning("")
-            logger.warning(f"###############################################")
-            logger.warning(f"#    Batch item: {item}")
-            logger.warning(f"# Failed with: {e}")
-            failure = f"{e}"
-            logger.warning(f"#          At:")
-            traceback.print_exc()
-            logger.warning(f"#######################################")
-            logger.warning("")
-            logger.warning("")
-        watchdog.stop()
-        # logger.info("SAFE EXECUTION FINISHED!")
-        return result, failure
-
-    def execute_one_cron(self):
-        """
-        Take ownership of one cron and make sure it is properly executed and updated with status underway
-        """
-        item = self.db.book_batch_item(self.db.PENDING, self.db.IN_PROGRESS)
-        if item:
-            logger.info("Processing item:")
-            logger.info(pformat(item))
-            id = item.get("id", None)
-            type = item.get("type", None)
-            updated_at = item.get("updated_at", None)
-            if id and type and updated_at:
-                entrypoint, failure = self.get_callable_for_type(type)
-                if entrypoint and failure:
-                    entrypoint = None
-                    failure = f"{failure} AND ENTRYPOINT WAS SET!"
-                result = None
-                if entrypoint:
-                    result, failure = self._execute_safely(entrypoint, item)
-                if failure:
-                    logger.warning("¤¤¤¤¤¤¤¤¤¤¤¤¤¤¤¤¤¤¤ CRON FILTER FAILED WITH ¤¤¤¤¤¤¤¤¤¤¤¤¤¤¤¤¤¤")
-                    logger.warning(failure)
-                    logger.warning("")
-                id2, updated_at2 = self.db.bump_batch_item(id, self.db.FAILED if failure else self.db.DONE, failure, updated_at) or (None, None)
-                logger.info(f"id2={id2}, updated_at2={updated_at2}, id={id}, updated_at={updated_at}")
-            else:
-                logger.warning(f"Missing data for item id={id}, type={type}, updated_at={updated_at}")
-
-        # else:
-        # logger.info(f"No pending items found")
 
     def get_now(self):
         return self.db.get_now()
@@ -188,6 +128,9 @@ class Processor:
         """
         return self.db.insert_cron_item({"priority": priority, "data": data, "type": type, "status": self.db.PENDING, "source": source})
 
+    def delete_cron(self, id):
+        self.db.delete_cron_with_id(id)
+
     def delete_all_crons(self, time_sec=30):
         self.db.delete_all()
 
